@@ -81,7 +81,13 @@ class IdnTest extends TestCase
             }
 
             [$line] = explode('#', $line);
-            [$source, $toUnicode, $toUnicodeStatus, $toAsciiN, $toAsciiNStatus, $toAsciiT, $toAsciiTStatus] = array_map('trim', explode(';', $line));
+            [$source, $toUnicode, $toUnicodeStatus, $toAsciiN, $toAsciiNStatus, $toAsciiT, $toAsciiTStatus] = preg_replace_callback(
+                '/\\\\(?:u([[:xdigit:]]{4})|x{([[:xdigit:]]{4})})/u',
+                static function (array $matches): string {
+                    return mb_chr(hexdec($matches[1]), 'utf-8');
+                },
+                array_map('trim', explode(';', $line))
+            );
 
             if ('' === $toUnicode) {
                 $toUnicode = $source;
@@ -126,7 +132,7 @@ class IdnTest extends TestCase
             $this->markTestSkipped('PHP Bug #72506.');
         }
 
-        if ($toUnicodeStatus === []) {
+        if ([] === $toUnicodeStatus) {
             $this->assertSame($toUnicode, $info['result']);
             $this->assertSame(0, $info['errors'], sprintf('Expected no errors, but found %d.', $info['errors']));
         } else {
@@ -154,7 +160,7 @@ class IdnTest extends TestCase
             $this->markTestSkipped('PHP Bug #72506.');
         }
 
-        if ($toAsciiNStatus === []) {
+        if ([] === $toAsciiNStatus) {
             $this->assertSame($toAsciiN, $info['result']);
             $this->assertSame(0, $info['errors'], sprintf('Expected no errors, but found %d.', $info['errors']));
         } else {
@@ -182,17 +188,7 @@ class IdnTest extends TestCase
             $this->markTestSkipped('PHP Bug #72506.');
         }
 
-        // There is currently a bug in the test data, where it is expected that the following 2
-        // source strings result in an empty string. However, due to the way the test files are setup
-        // it currently isn't possible to represent an empty string as an expected value. So, we
-        // skip these 2 problem tests. I have notified the Unicode Consortium about this and they
-        // have passed the information along to the spec editors.
-        // U+200C or U+200D
-        if ("\xE2\x80\x8C" === $source || "\xE2\x80\x8D" === $source) {
-            $toAsciiT = '';
-        }
-
-        if ($toAsciiTStatus === []) {
+        if ([] === $toAsciiTStatus) {
             $this->assertSame($toAsciiT, $info['result']);
             $this->assertSame(0, $info['errors'], sprintf('Expected no errors, but found %d.', $info['errors']));
         } else {
