@@ -27,7 +27,7 @@ class Php81Test extends TestCase
         $this->assertFalse(array_is_list([0 => 'a', 2 => 'b']));
         $this->assertFalse(array_is_list([1 => 'a', 2 => 'b']));
 
-        $x = ['key' => 2, NAN];
+        $x = ['key' => 2, \NAN];
         unset($x['key']);
         $this->assertTrue(array_is_list($x));
     }
@@ -37,7 +37,7 @@ class Php81Test extends TestCase
      */
     public function testMysqliRefreshReplicaDefined()
     {
-        $this->assertTrue(defined('MYSQLI_REFRESH_REPLICA'));
+        $this->assertTrue(\defined('MYSQLI_REFRESH_REPLICA'));
         $this->assertSame(MYSQLI_REFRESH_SLAVE, MYSQLI_REFRESH_REPLICA);
     }
 }
